"""NextDNS constants."""
from .model import (
    ApiNames,
    ParentalControlCategories,
    ParentalControlCategoriesAttrs,
    ParentalControlServices,
    ParentalControlServicesAttrs,
    SettingDescription,
)

API_ENDPOINT = "https://api.nextdns.io"

ATTR_ANALYTICS = "analytics"
ATTR_CLEAR_LOGS = "clear_logs"
ATTR_ENABLED = "enabled"
ATTR_GET_LOGS = "get_logs"
ATTR_PARENTAL_CONTROL = "parental_control"
ATTR_PARENTAL_CONTROL_CATEGORIES = "parental_control_categories"
ATTR_PARENTAL_CONTROL_CATEGORY = "parental_control_category"
ATTR_PARENTAL_CONTROL_SERVICE = "parental_control_service"
ATTR_PARENTAL_CONTROL_SERVICES = "parental_control_services"
ATTR_PERFORMANCE = "performance"
ATTR_PRIVACY = "privacy"
ATTR_PROFILE = "profile"
ATTR_PROFILES = "profiles"
ATTR_SECURITY = "security"
ATTR_SECURITY = "security"
ATTR_SETTINGS = "settings"
ATTR_TEST = "test"

ATTR_ANONYMIZED_ECS = "anonymized_ecs"
ATTR_BLOCK_PAGE = "block_page"
ATTR_CACHE_BOOST = "cache_boost"
ATTR_CNAME_FLATTENING = "cname_flattening"
ATTR_LOGS = "logs"
ATTR_LOGS_LOCATION = "logs_location"
ATTR_LOGS_RETENTION = "logs_retention"
ATTR_RETENTION = "retention"
ATTR_LOCATION = "location"
ATTR_WEB3 = "web3"

ATTR_ALLOW_AFFILIATE = "allow_affiliate"
ATTR_BLOCK_DISGUISED_TRACKERS = "block_disguised_trackers"

ATTR_AI_THREAT_DETECTION = "ai_threat_detection"
ATTR_BLOCK_CSAM = "block_csam"
ATTR_BLOCK_DDNS = "block_ddns"
ATTR_BLOCK_NRD = "block_nrd"
ATTR_BLOCK_PARKED_DOMAINS = "block_parked_domains"
ATTR_CRYPTOJACKING_PROTECTION = "cryptojacking_protection"
ATTR_DGA_PROTECTION = "dga_protection"
ATTR_DNS_REBINDING_PROTECTION = "dns_rebinding_protection"
ATTR_GOOGLE_SAFE_BROWSING = "google_safe_browsing"
ATTR_IDN_HOMOGRAPH_ATTACKS_PROTECTION = "idn_homograph_attacks_protection"
ATTR_THREAT_INTELLIGENCE_FEEDS = "threat_intelligence_feeds"
ATTR_TYPOSQUATTING_PROTECTION = "typosquatting_protection"

ATTR_BLOCK_BYPASS_METHODS = "block_bypass_methods"
ATTR_SAFESEARCH = "safesearch"
ATTR_YOUTUBE_RESTRICTED_MODE = "youtube_restricted_mode"

PARENTAL_CONTROL_CATEGORIES = tuple(item for item in ParentalControlCategoriesAttrs)
PARENTAL_CONTROL_SERVICES = tuple(item for item in ParentalControlServicesAttrs)

ENDPOINTS = {
    ATTR_ANALYTICS: "https://api.nextdns.io/profiles/{profile_id}/analytics/{type}",
    ATTR_CLEAR_LOGS: "https://api.nextdns.io/profiles/{profile_id}/logs",
    ATTR_GET_LOGS: "https://api.nextdns.io/profiles/{profile_id}/logs/download",
    ATTR_PROFILE: "https://api.nextdns.io/profiles/{profile_id}",
    ATTR_PROFILES: "https://api.nextdns.io/profiles",
    ATTR_TEST: "https://{profile_id}.test.nextdns.io",
    ATTR_SECURITY: "https://api.nextdns.io/profiles/{profile_id}/security",
    ATTR_SETTINGS: "https://api.nextdns.io/profiles/{profile_id}/settings",
    ATTR_PERFORMANCE: "https://api.nextdns.io/profiles/{profile_id}/settings/performance",
    ATTR_PRIVACY: "https://api.nextdns.io/profiles/{profile_id}/privacy",
    ATTR_PARENTAL_CONTROL: "https://api.nextdns.io/profiles/{profile_id}/parentalControl",
    ATTR_PARENTAL_CONTROL_CATEGORY: "https://api.nextdns.io/profiles/{profile_id}/parentalControl/categories/{category}",
    ATTR_PARENTAL_CONTROL_CATEGORIES: "https://api.nextdns.io/profiles/{profile_id}/parentalControl/categories",
    ATTR_PARENTAL_CONTROL_SERVICE: "https://api.nextdns.io/profiles/{profile_id}/parentalControl/services/{service}",
    ATTR_PARENTAL_CONTROL_SERVICES: "https://api.nextdns.io/profiles/{profile_id}/parentalControl/services",
    ATTR_LOGS: "https://api.nextdns.io/profiles/{profile_id}/settings/logs",
    ATTR_LOGS_LOCATION: "https://api.nextdns.io/profiles/{profile_id}/settings/logs/location",
    ATTR_LOGS_RETENTION: "https://api.nextdns.io/profiles/{profile_id}/settings/logs/retention",
    ATTR_BLOCK_PAGE: "https://api.nextdns.io/profiles/{profile_id}/settings/blockPage",
}

MAP_DNSSEC = {False: "not_validated_queries", True: "validated_queries"}
MAP_ENCRYPTED = {False: "unencrypted_queries", True: "encrypted_queries"}
MAP_IP_VERSIONS = {4: "ipv4_queries", 6: "ipv6_queries"}
MAP_PROFILE = {"parentalControl": "parental_control"}
MAP_PROTOCOLS = {
    "DNS-over-HTTPS": "doh_queries",
    "DNS-over-HTTP/3": "doh3_queries",
    "DNS-over-QUIC": "doq_queries",
    "DNS-over-TLS": "dot_queries",
    "TCP": "tcp_queries",
    "UDP": "udp_queries",
}
MAP_STATUS = {
    "allowed": "allowed_queries",
    "blocked": "blocked_queries",
    "default": "default_queries",
    "relayed": "relayed_queries",
}

MAP_SETTING = {
    ATTR_BLOCK_PAGE: SettingDescription(ENDPOINTS[ATTR_BLOCK_PAGE], ATTR_ENABLED),
    ATTR_CACHE_BOOST: SettingDescription(
        ENDPOINTS[ATTR_PERFORMANCE], ApiNames.CACHE_BOOST
    ),
    ATTR_CNAME_FLATTENING: SettingDescription(
        ENDPOINTS[ATTR_PERFORMANCE], ApiNames.CNAME_FLATTENING
    ),
    ATTR_ANONYMIZED_ECS: SettingDescription(ENDPOINTS[ATTR_PERFORMANCE], ApiNames.ECS),
    ATTR_WEB3: SettingDescription(ENDPOINTS[ATTR_SETTINGS], ATTR_WEB3),
    ATTR_LOGS: SettingDescription(ENDPOINTS[ATTR_LOGS], ATTR_ENABLED),
    ATTR_LOGS_LOCATION: SettingDescription(ENDPOINTS[ATTR_LOGS], ATTR_LOCATION),
    ATTR_LOGS_RETENTION: SettingDescription(ENDPOINTS[ATTR_LOGS], ATTR_RETENTION),
    ATTR_ALLOW_AFFILIATE: SettingDescription(
        ENDPOINTS[ATTR_PRIVACY], ApiNames.ALLOW_AFFILIATE
    ),
    ATTR_BLOCK_DISGUISED_TRACKERS: SettingDescription(
        ENDPOINTS[ATTR_PRIVACY], ApiNames.DISGUISED_TRACKERS
    ),
    ATTR_AI_THREAT_DETECTION: SettingDescription(
        ENDPOINTS[ATTR_SECURITY], ApiNames.AI_THREAT_TETECTION
    ),
    ATTR_BLOCK_CSAM: SettingDescription(ENDPOINTS[ATTR_SECURITY], ApiNames.CSAM),
    ATTR_BLOCK_DDNS: SettingDescription(ENDPOINTS[ATTR_SECURITY], ApiNames.DDNS),
    ATTR_BLOCK_NRD: SettingDescription(ENDPOINTS[ATTR_SECURITY], ApiNames.NRD),
    ATTR_BLOCK_PARKED_DOMAINS: SettingDescription(
        ENDPOINTS[ATTR_SECURITY], ApiNames.PARKING
    ),
    ATTR_CRYPTOJACKING_PROTECTION: SettingDescription(
        ENDPOINTS[ATTR_SECURITY], ApiNames.CRYPTOJACKING
    ),
    ATTR_DGA_PROTECTION: SettingDescription(ENDPOINTS[ATTR_SECURITY], ApiNames.DGA),
    ATTR_DNS_REBINDING_PROTECTION: SettingDescription(
        ENDPOINTS[ATTR_SECURITY], ApiNames.DNS_REBINDING
    ),
    ATTR_GOOGLE_SAFE_BROWSING: SettingDescription(
        ENDPOINTS[ATTR_SECURITY], ApiNames.GOOGLE_SAFE_BROWSING
    ),
    ATTR_IDN_HOMOGRAPH_ATTACKS_PROTECTION: SettingDescription(
        ENDPOINTS[ATTR_SECURITY], ApiNames.IDN_HOMOGRAPHS
    ),
    ATTR_THREAT_INTELLIGENCE_FEEDS: SettingDescription(
        ENDPOINTS[ATTR_SECURITY], ApiNames.THREAT_INTELLIGENCE_FEEDS
    ),
    ATTR_TYPOSQUATTING_PROTECTION: SettingDescription(
        ENDPOINTS[ATTR_SECURITY], ApiNames.TYPOSQUATTING
    ),
    ATTR_BLOCK_BYPASS_METHODS: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL], ApiNames.BLOCK_BYPASS
    ),
    ATTR_SAFESEARCH: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL], ApiNames.SAFESEARCH
    ),
    ATTR_YOUTUBE_RESTRICTED_MODE: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL], ApiNames.YOUTUBE_RESTRICTED_MODE
    ),
    ParentalControlServicesAttrs.BLOCK_TIKTOK: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.TIKTOK
    ),
    ParentalControlServicesAttrs.BLOCK_TINDER: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.TINDER
    ),
    ParentalControlServicesAttrs.BLOCK_FACEBOOK: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.FACEBOOK
    ),
    ParentalControlServicesAttrs.BLOCK_SNAPCHAT: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.SNAPCHAT
    ),
    ParentalControlServicesAttrs.BLOCK_INSTAGRAM: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.INSTAGRAM
    ),
    ParentalControlServicesAttrs.BLOCK_FORTNITE: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.FORTNITE
    ),
    ParentalControlServicesAttrs.BLOCK_MESSENGER: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.MESSENGER
    ),
    ParentalControlServicesAttrs.BLOCK_LEAGUEOFLEGENDS: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE],
        ParentalControlServices.LEAGUEOFLEGENDS,
    ),
    ParentalControlServicesAttrs.BLOCK_VK: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.VK
    ),
    ParentalControlServicesAttrs.BLOCK_9GAG: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.NINEGAG
    ),
    ParentalControlServicesAttrs.BLOCK_TUMBLR: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.TUMBLR
    ),
    ParentalControlServicesAttrs.BLOCK_ROBLOX: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.ROBLOX
    ),
    ParentalControlServicesAttrs.BLOCK_TWITCH: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.TWITCH
    ),
    ParentalControlServicesAttrs.BLOCK_MINECRAFT: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.MINECRAFT
    ),
    ParentalControlServicesAttrs.BLOCK_TWITTER: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.TWITTER
    ),
    ParentalControlServicesAttrs.BLOCK_DISCORD: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.DISCORD
    ),
    ParentalControlServicesAttrs.BLOCK_DAILYMOTION: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.DAILYMOTION
    ),
    ParentalControlServicesAttrs.BLOCK_PINTEREST: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.PINTEREST
    ),
    ParentalControlServicesAttrs.BLOCK_YOUTUBE: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.YOUTUBE
    ),
    ParentalControlServicesAttrs.BLOCK_STEAM: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.STEAM
    ),
    ParentalControlServicesAttrs.BLOCK_HULU: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.HULU
    ),
    ParentalControlServicesAttrs.BLOCK_WHATSAPP: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.WHATSAPP
    ),
    ParentalControlServicesAttrs.BLOCK_REDDIT: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.REDDIT
    ),
    ParentalControlServicesAttrs.BLOCK_BLIZZARD: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.BLIZZARD
    ),
    ParentalControlServicesAttrs.BLOCK_NETFLIX: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.NETFLIX
    ),
    ParentalControlServicesAttrs.BLOCK_IMGUR: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.IMGUR
    ),
    ParentalControlServicesAttrs.BLOCK_TELEGRAM: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.TELEGRAM
    ),
    ParentalControlServicesAttrs.BLOCK_DISNEYPLUS: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.DISNEYPLUS
    ),
    ParentalControlServicesAttrs.BLOCK_VIMEO: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.VIMEO
    ),
    ParentalControlServicesAttrs.BLOCK_SKYPE: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE],
        ParentalControlServices.SKYPE,
    ),
    ParentalControlServicesAttrs.BLOCK_EBAY: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.EBAY
    ),
    ParentalControlServicesAttrs.BLOCK_SPOTIFY: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.SPOTIFY
    ),
    ParentalControlServicesAttrs.BLOCK_PRIMEVIDEO: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.PRIMEVIDEO
    ),
    ParentalControlServicesAttrs.BLOCK_ZOOM: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.ZOOM
    ),
    ParentalControlServicesAttrs.BLOCK_AMAZON: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.AMAZON
    ),
    ParentalControlServicesAttrs.BLOCK_XBOXLIVE: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.XBOXLIVE
    ),
    ParentalControlServicesAttrs.BLOCK_SIGNAL: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_SERVICE], ParentalControlServices.SIGNAL
    ),
    ParentalControlCategoriesAttrs.BLOCK_DATING: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY], ParentalControlCategories.DATING
    ),
    ParentalControlCategoriesAttrs.BLOCK_GAMBLING: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY], ParentalControlCategories.GAMBLING
    ),
    ParentalControlCategoriesAttrs.BLOCK_PIRACY: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY], ParentalControlCategories.PIRACY
    ),
    ParentalControlCategoriesAttrs.BLOCK_PORN: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY], ParentalControlCategories.PORN
    ),
    ParentalControlCategoriesAttrs.BLOCK_SOCIAL_NETWORKS: SettingDescription(
        ENDPOINTS[ATTR_PARENTAL_CONTROL_CATEGORY],
        ParentalControlCategories.SOCIAL_NETWORKS,
    ),
}

ALLOWED_LOGS_LOCATION = ("ch", "eu", "gb", "us")
ALLOWED_LOGS_RETENTION = (1, 6, 24, 168, 720, 2160, 4320, 8760, 17520)



"""Type definitions for NextDNS."""
from __future__ import annotations

from dataclasses import dataclass
from enum import Enum
from typing import Any, TypeVar

_StrEnumSelfT = TypeVar("_StrEnumSelfT", bound="StrEnum")


class StrEnum(str, Enum):
    """Partial backport of Python 3.11's StrEnum for our basic use cases."""

    def __new__(
        cls: type[_StrEnumSelfT], value: str, *args: Any, **kwargs: Any
    ) -> _StrEnumSelfT:
        """Create a new StrEnum instance."""
        if not isinstance(value, str):
            raise TypeError(f"{value!r} is not a string")
        return super().__new__(cls, value, *args, **kwargs)

    def __str__(self) -> str:
        """Return self.value."""
        return str(self.value)

    @staticmethod
    def _generate_next_value_(
        name: str, start: int, count: int, last_values: list[Any]
    ) -> Any:
        """Make `auto()` explicitly unsupported."""
        raise TypeError("auto() is not supported by this implementation")


@dataclass
class NextDnsData:
    """NextDNS data class."""


@dataclass
class AnalyticsStatus(NextDnsData):
    """AnalyticsStatus class."""

    all_queries: int = 0
    allowed_queries: int = 0
    blocked_queries: int = 0
    default_queries: int = 0
    relayed_queries: int = 0
    blocked_queries_ratio: float = 0

    def __post_init__(self) -> None:
        """Call after initialization."""
        self.all_queries = sum(
            [
                self.default_queries,
                self.blocked_queries,
                self.allowed_queries,
                self.relayed_queries,
            ]
        )

        self.blocked_queries_ratio = (
            0
            if not self.all_queries
            else round(self.blocked_queries / self.all_queries * 100, 1)
        )


@dataclass
class AnalyticsDnssec(NextDnsData):
    """AnalyticsDnssec class."""

    not_validated_queries: int = 0
    validated_queries: int = 0
    validated_queries_ratio: float = 0

    def __post_init__(self) -> None:
        """Call after initialization."""
        all_queries = sum([self.validated_queries, self.not_validated_queries])

        self.validated_queries_ratio = (
            0
            if not all_queries
            else round(self.validated_queries / all_queries * 100, 1)
        )


@dataclass
class AnalyticsEncryption(NextDnsData):
    """AnalyticsEncryption class."""

    encrypted_queries: int = 0
    unencrypted_queries: int = 0
    encrypted_queries_ratio: float = 0

    def __post_init__(self) -> None:
        """Call after initialization."""
        all_queries = sum([self.encrypted_queries, self.unencrypted_queries])

        self.encrypted_queries_ratio = (
            0
            if not all_queries
            else round(self.encrypted_queries / all_queries * 100, 1)
        )


@dataclass
class AnalyticsIpVersions(NextDnsData):
    """AnalyticsIpVersions class."""

    ipv6_queries: int = 0
    ipv4_queries: int = 0
    ipv6_queries_ratio: float = 0

    def __post_init__(self) -> None:
        """Call after initialization."""
        all_queries = sum([self.ipv6_queries, self.ipv4_queries])

        self.ipv6_queries_ratio = (
            0 if not all_queries else round(self.ipv6_queries / all_queries * 100, 1)
        )


@dataclass
class AnalyticsProtocols(NextDnsData):
    """AnalyticsProtocols class."""

    doh_queries: int = 0
    doh3_queries: int = 0
    doq_queries: int = 0
    dot_queries: int = 0
    tcp_queries: int = 0
    udp_queries: int = 0
    doh_queries_ratio: float = 0
    doh3_queries_ratio: float = 0
    doq_queries_ratio: float = 0
    dot_queries_ratio: float = 0
    tcp_queries_ratio: float = 0
    udp_queries_ratio: float = 0

    def __post_init__(self) -> None:
        """Call after initialization."""
        all_queries = sum(
            [
                self.doh_queries,
                self.doh3_queries,
                self.doq_queries,
                self.dot_queries,
                self.tcp_queries,
                self.udp_queries,
            ]
        )

        self.doh_queries_ratio = (
            0 if not all_queries else round(self.doh_queries / all_queries * 100, 1)
        )
        self.doh3_queries_ratio = (
            0 if not all_queries else round(self.doh3_queries / all_queries * 100, 1)
        )
        self.doq_queries_ratio = (
            0 if not all_queries else round(self.doq_queries / all_queries * 100, 1)
        )
        self.dot_queries_ratio = (
            0 if not all_queries else round(self.dot_queries / all_queries * 100, 1)
        )
        self.tcp_queries_ratio = (
            0 if not all_queries else round(self.tcp_queries / all_queries * 100, 1)
        )
        self.udp_queries_ratio = (
            0 if not all_queries else round(self.udp_queries / all_queries * 100, 1)
        )


@dataclass
class AllAnalytics(NextDnsData):
    """AllAnalytics class."""

    dnssec: AnalyticsDnssec
    encryption: AnalyticsEncryption
    ip_versions: AnalyticsIpVersions
    protocols: AnalyticsProtocols
    status: AnalyticsStatus


@dataclass
class Profile(NextDnsData):
    """Profile class."""

    allowlist: list[dict[str, Any]]
    denylist: list[dict[str, Any]]
    fingerprint: str
    id: str  # noqa: A003
    name: str
    parental_control: dict[str, Any]
    privacy: dict[str, Any]
    rewrites: list
    security: dict[str, Any]
    settings: dict[str, Any]
    setup: dict[str, Any]


@dataclass
class Settings(NextDnsData):
    """Settings class."""

    block_page: bool
    cache_boost: bool
    cname_flattening: bool
    anonymized_ecs: bool
    logs: bool
    logs_location: str
    logs_retention: int
    web3: bool

    allow_affiliate: bool
    block_disguised_trackers: bool

    ai_threat_detection: bool
    block_csam: bool
    block_ddns: bool
    block_nrd: bool
    block_parked_domains: bool
    cryptojacking_protection: bool
    dga_protection: bool
    dns_rebinding_protection: bool
    google_safe_browsing: bool
    idn_homograph_attacks_protection: bool
    threat_intelligence_feeds: bool
    typosquatting_protection: bool

    block_bypass_methods: bool
    safesearch: bool
    youtube_restricted_mode: bool

    block_9gag: bool
    block_amazon: bool
    block_blizzard: bool
    block_dailymotion: bool
    block_discord: bool
    block_disneyplus: bool
    block_ebay: bool
    block_facebook: bool
    block_fortnite: bool
    block_hulu: bool
    block_imgur: bool
    block_instagram: bool
    block_leagueoflegends: bool
    block_messenger: bool
    block_minecraft: bool
    block_netflix: bool
    block_pinterest: bool
    block_primevideo: bool
    block_reddit: bool
    block_roblox: bool
    block_signal: bool
    block_skype: bool
    block_snapchat: bool
    block_spotify: bool
    block_steam: bool
    block_telegram: bool
    block_tiktok: bool
    block_tinder: bool
    block_tumblr: bool
    block_twitch: bool
    block_twitter: bool
    block_vimeo: bool
    block_vk: bool
    block_whatsapp: bool
    block_xboxlive: bool
    block_youtube: bool
    block_zoom: bool

    block_dating: bool
    block_gambling: bool
    block_piracy: bool
    block_porn: bool
    block_social_networks: bool


@dataclass
class ProfileInfo(NextDnsData):
    """ProfileInfo class."""

    id: str  # noqa: A003
    fingerprint: str
    name: str


@dataclass
class ConnectionStatus(NextDnsData):
    """ConnectionStatus class."""

    connected: bool
    profile_id: str | None = None


class ParentalControlServices(StrEnum):
    """Service type for parental control."""

    AMAZON = "amazon"
    BLIZZARD = "blizzard"
    DAILYMOTION = "dailymotion"
    DISCORD = "discord"
    DISNEYPLUS = "disneyplus"
    EBAY = "ebay"
    FACEBOOK = "facebook"
    FORTNITE = "fortnite"
    HULU = "hulu"
    IMGUR = "imgur"
    INSTAGRAM = "instagram"
    LEAGUEOFLEGENDS = "leagueoflegends"
    MESSENGER = "messenger"
    MINECRAFT = "minecraft"
    NETFLIX = "netflix"
    NINEGAG = "9gag"
    PINTEREST = "pinterest"
    PRIMEVIDEO = "primevideo"
    REDDIT = "reddit"
    ROBLOX = "roblox"
    SIGNAL = "signal"
    SKYPE = "skype"
    SNAPCHAT = "snapchat"
    SPOTIFY = "spotify"
    STEAM = "steam"
    TELEGRAM = "telegram"
    TIKTOK = "tiktok"
    TINDER = "tinder"
    TUMBLR = "tumblr"
    TWITCH = "twitch"
    TWITTER = "twitter"
    VIMEO = "vimeo"
    VK = "vk"
    WHATSAPP = "whatsapp"
    XBOXLIVE = "xboxlive"
    YOUTUBE = "youtube"
    ZOOM = "zoom"


class ParentalControlServicesAttrs(StrEnum):
    """Service type attributes for parental control."""

    BLOCK_9GAG = "block_9gag"
    BLOCK_AMAZON = "block_amazon"
    BLOCK_BLIZZARD = "block_blizzard"
    BLOCK_DAILYMOTION = "block_dailymotion"
    BLOCK_DISCORD = "block_discord"
    BLOCK_DISNEYPLUS = "block_disneyplus"
    BLOCK_EBAY = "block_ebay"
    BLOCK_FACEBOOK = "block_facebook"
    BLOCK_FORTNITE = "block_fortnite"
    BLOCK_HULU = "block_hulu"
    BLOCK_IMGUR = "block_imgur"
    BLOCK_INSTAGRAM = "block_instagram"
    BLOCK_LEAGUEOFLEGENDS = "block_leagueoflegends"
    BLOCK_MESSENGER = "block_messenger"
    BLOCK_MINECRAFT = "block_minecraft"
    BLOCK_NETFLIX = "block_netflix"
    BLOCK_PINTEREST = "block_pinterest"
    BLOCK_PRIMEVIDEO = "block_primevideo"
    BLOCK_REDDIT = "block_reddit"
    BLOCK_ROBLOX = "block_roblox"
    BLOCK_SIGNAL = "block_signal"
    BLOCK_SKYPE = "block_skype"
    BLOCK_SNAPCHAT = "block_snapchat"
    BLOCK_SPOTIFY = "block_spotify"
    BLOCK_STEAM = "block_steam"
    BLOCK_TELEGRAM = "block_telegram"
    BLOCK_TIKTOK = "block_tiktok"
    BLOCK_TINDER = "block_tinder"
    BLOCK_TUMBLR = "block_tumblr"
    BLOCK_TWITCH = "block_twitch"
    BLOCK_TWITTER = "block_twitter"
    BLOCK_VIMEO = "block_vimeo"
    BLOCK_VK = "block_vk"
    BLOCK_WHATSAPP = "block_whatsapp"
    BLOCK_XBOXLIVE = "block_xboxlive"
    BLOCK_YOUTUBE = "block_youtube"
    BLOCK_ZOOM = "block_zoom"


class ParentalControlCategories(StrEnum):
    """Categories type for parental control."""

    DATING = "dating"
    GAMBLING = "gambling"
    PIRACY = "piracy"
    PORN = "porn"
    SOCIAL_NETWORKS = "social-networks"


class ParentalControlCategoriesAttrs(StrEnum):
    """Categories type attributes for parental control."""

    BLOCK_DATING = "block_dating"
    BLOCK_GAMBLING = "block_gambling"
    BLOCK_PIRACY = "block_piracy"
    BLOCK_PORN = "block_porn"
    BLOCK_SOCIAL_NETWORKS = "block_social_networks"


class ApiNames(StrEnum):
    """Names type for API."""

    AI_THREAT_TETECTION = "aiThreatDetection"
    ALLOW_AFFILIATE = "allowAffiliate"
    BLOCK_BYPASS = "blockBypass"
    CACHE_BOOST = "cacheBoost"
    CATEGORIES = "categories"
    CNAME_FLATTENING = "cnameFlattening"
    CRYPTOJACKING = "cryptojacking"
    CSAM = "csam"
    DDNS = "ddns"
    DGA = "dga"
    DISGUISED_TRACKERS = "disguisedTrackers"
    DNS_REBINDING = "dnsRebinding"
    ECS = "ecs"
    GOOGLE_SAFE_BROWSING = "googleSafeBrowsing"
    IDN_HOMOGRAPHS = "idnHomographs"
    NRD = "nrd"
    PARKING = "parking"
    SAFESEARCH = "safeSearch"
    SERVICES = "services"
    THREAT_INTELLIGENCE_FEEDS = "threatIntelligenceFeeds"
    TYPOSQUATTING = "typosquatting"
    YOUTUBE_RESTRICTED_MODE = "youtubeRestrictedMode"


@dataclass
class SettingDescription:
    """SettingDescription class."""

    url: str
    name: str
